Learn R Programming

zetadiv (version 1.1.1)

Plot.ispline: Plotting splines from I-spline-based multi-site generalised dissimilarity modelling

Description

Plots the I-splines resulting from Zeta.msgdm.

Usage

Plot.ispline(msgdm, data.env, distance = FALSE, my.order = NULL,
  biotic = FALSE, order.ispline = 2, kn.ispline = 1, pch = NULL,
  lty = NULL, legend = TRUE, lwd = 1, cex = 1)

Arguments

msgdm

Output of function Zeta.msgdm computed with reg.type = ispline.

data.env

Site-by-variable data frame used for the computation of msgdm, with sites as rows and environmental variables as columns.

distance

Boolean, indicates is distance was used in the computation of msgdm.

my.order

Zeta order, necessary to draw the line for categorical variables.

biotic

Boolean, indicates is zeta diversity from another community was used in the computation of msgdm.

order.ispline

Order of the I-spline.

kn.ispline

Number of knots in the I-spline.

pch

Shapes of the points to be used in the plotting. If nothing is provided, pch is a sequence of integers from 1 to the number of variables used for the computation of msgdm.

lty

Line types to be used in the plotting. If nothing is provided, pch is a sequence of integers from 1 to the number of variables used for the computation of msgdm.

legend

Boolean, indicates if the legend must be drawn.

lwd

Line width.

cex

Point size.

Value

A plot of the I-splines computed by Zeta.msgdm with reg.type = ispline. All splines are drawned on the same plot, and their ranges are rescaled between 0 and 1 for comparison.

See Also

Zeta.msgdm, Ispline

Examples

Run this code
# NOT RUN {
utils::data(Marion.species)
xy.marion <- Marion.species[1:2]
data.spec.marion <- Marion.species[3:33]

utils::data(Marion.env)
data.env.marion <- Marion.env[3]

zeta.ispline <- Zeta.msgdm(data.spec.marion, data.env.marion, xy.marion, sam = 100,
    order = 3, normalize = "Jaccard", reg.type = "ispline")
zeta.ispline
dev.new()
Plot.ispline(zeta.ispline, data.env.marion, distance = TRUE)

# }

Run the code above in your browser using DataLab